@@ -13,7 +13,7 @@ use Socket;
 use Storable;
 use vars qw($VERSION);
 
-$VERSION = '1.04';
+$VERSION = '1.05';
 
 sub spawn {
   my $package = shift;
@@ -695,7 +695,8 @@ sub SMTPD_message {
   my $buf = ${ $_[3] };
   my $msg_id = Email::MessageID->new;
   my $uid = $msg_id->user();
-  unshift @{ $buf }, "Message-ID: <$uid\@" . $self->{hostname} . '>';
+  unshift @{ $buf }, "Message-ID: <$uid\@" . $self->{hostname} . '>' 
+	unless grep { /^Message-ID:/i } @{ $buf };
   unshift @{ $buf }, "Received: from Unknown [" . $self->{clients}->{ $id }->{peeraddr} . "] by " . $self->{hostname} . " " . __PACKAGE__ . "-$VERSION with SMTP id $uid; " . strftime("%a, %d %b %Y %H:%M:%S %z", localtime); 
   $self->send_to_client( $id, "250 $uid Message accepted for delivery" );
   my $email = Email::Simple->new( join "\r\n", @{ $buf } );
